@@ -6,16 +6,15 @@ Binning process.
 # Copyright (C) 2020
 
 import numbers
-import pickle
 import time
 
-from multiprocessing import cpu_count
-from multiprocessing import Pool
 from warnings import warn
 
+import dill
 import numpy as np
 import pandas as pd
 
+from joblib import Parallel, delayed, effective_n_jobs
 from sklearn.base import BaseEstimator
 from sklearn.exceptions import NotFittedError
 from sklearn.utils import check_array
@@ -58,16 +57,6 @@ _OPTB_TYPES = (OptimalBinning, ContinuousOptimalBinning,
 _OPTBPW_TYPES = (OptimalPWBinning, ContinuousOptimalPWBinning)
 
 
-def _effective_n_jobs(n_jobs):
-    # Joblib check
-    if n_jobs is None:
-        n_jobs = 1
-    elif n_jobs < 0:
-        n_jobs = max(cpu_count() + 1 + n_jobs, 1)
-
-    return n_jobs
-
-
 def _read_column(input_path, extension, column, **kwargs):
     if extension == "csv":
         x = pd.read_csv(input_path, engine='c', usecols=[column],
@@ -322,7 +311,7 @@ class BaseBinningProcess:
             raise TypeError("path must be a string.")
 
         with open(path, "rb") as f:
-            return pickle.load(f)
+            return dill.load(f)
 
     def save(self, path):
         """Save binning process to pickle file.
@@ -336,7 +325,7 @@ class BaseBinningProcess:
             raise TypeError("path must be a string.")
 
         with open(path, "wb") as f:
-            pickle.dump(self, f)
+            dill.dump(self, f)
 
     def _support_selection_criteria(self):
         self._support = np.full(self._n_variables, True, dtype=bool)
@@ -1054,7 +1043,7 @@ class BinningProcess(Base, BaseEstimator, BaseBinningProcess):
                               .format(self._n_variables))
 
         # Number of jobs
-        n_jobs = _effective_n_jobs(self.n_jobs)
+        n_jobs = effective_n_jobs(self.n_jobs)
 
         if self.verbose:
             self._logger.info("Options: number of jobs (cores): {}."
@@ -1086,37 +1075,36 @@ class BinningProcess(Base, BaseEstimator, BaseBinningProcess):
                 self._variable_dtypes[name] = dtype
                 self._binned_variables[name] = optb
         else:
-            pool = Pool(processes=n_jobs)
-
             ids = np.arange(len(self.variable_names))
             id_blocks = np.array_split(ids, n_jobs)
             names = np.asarray(self.variable_names)
 
             if isinstance(X, np.ndarray):
-                blocks = [pool.apply_async(
-                    _fit_block, args=(
+                blocks = Parallel(n_jobs=n_jobs, prefer="threads")(
+                    delayed(_fit_block)(
                         X[:, id_block], y, names[id_block],
                         self._target_dtype, self.categorical_variables,
                         self.binning_fit_params, self.max_n_prebins,
                         self.min_prebin_size, self.min_n_bins,
                         self.max_n_bins, self.min_bin_size,
                         self.max_pvalue, self.max_pvalue_policy,
-                        self.special_codes, self.split_digits))
-                         for id_block in id_blocks]
+                        self.special_codes, self.split_digits)
+                    for id_block in id_blocks)
+
             else:
-                blocks = [pool.apply_async(
-                    _fit_block, args=(
+                blocks = Parallel(n_jobs=n_jobs, prefer="threads")(
+                    delayed(_fit_block)(
                         X[names[id_block]], y, names[id_block],
                         self._target_dtype, self.categorical_variables,
                         self.binning_fit_params, self.max_n_prebins,
                         self.min_prebin_size, self.min_n_bins,
                         self.max_n_bins, self.min_bin_size,
                         self.max_pvalue, self.max_pvalue_policy,
-                        self.special_codes, self.split_digits))
-                         for id_block in id_blocks]
+                        self.special_codes, self.split_digits)
+                    for id_block in id_blocks)
 
             for b in blocks:
-                vt, bv = b.get()
+                vt, bv = b
                 self._variable_dtypes.update(vt)
                 self._binned_variables.update(bv)
 
@@ -1350,6 +1338,7 @@ class BinningProcess(Base, BaseEstimator, BaseBinningProcess):
             if self.binning_transform_params is not None:
                 params = self.binning_transform_params.get(name, {})
 
+            metric = params.get("metric", metric)
             metric_missing = params.get("metric_missing", metric_missing)
             metric_special = params.get("metric_special", metric_special)
 
@@ -1365,9 +1354,7 @@ class BinningProcess(Base, BaseEstimator, BaseBinningProcess):
             if isinstance(optb, _OPTBPW_TYPES):
                 tparams.pop("show_digits")
 
-            if metric is not None:
-                tparams["metric"] = params.get("metric", metric)
-            else:
+            if metric is None:
                 tparams.pop("metric")
 
             X_transform[:, i] = optb.transform(**tparams)
@@ -1424,6 +1411,7 @@ class BinningProcess(Base, BaseEstimator, BaseBinningProcess):
                 if self.binning_transform_params is not None:
                     params = self.binning_transform_params.get(name, {})
 
+                metric = params.get("metric", metric)
                 metric_missing = params.get("metric_missing", metric_missing)
                 metric_special = params.get("metric_special", metric_special)
 
@@ -1438,9 +1426,7 @@ class BinningProcess(Base, BaseEstimator, BaseBinningProcess):
                 if isinstance(optb, _OPTBPW_TYPES):
                     tparams.pop("show_digits")
 
-                if metric is not None:
-                    tparams["metric"] = params.get("metric", metric)
-                else:
+                if metric is None:
                     tparams.pop("metric")
 
                 X_transform[:, i] = optb.transform(**tparams)
