@@ -5,8 +5,7 @@ Base optimal binning sketch algorithm class.
 # Guillermo Navas-Palencia <g.navas.palencia@gmail.com>
 # Copyright (C) 2021
 
-from sklearn.exceptions import NotFittedError
-
+from ...exceptions import NotSolvedError
 from ...logging import Logger
 
 
@@ -24,6 +23,6 @@ class BaseSketch:
 
     def _check_is_solved(self):
         if not self._is_solved:
-            raise NotFittedError("This {} instance is not solved yet. Call "
+            raise NotSolvedError("This {} instance is not solved yet. Call "
                                  "'solve' with appropriate arguments."
                                  .format(self.__class__.__name__))
