@@ -1,10 +1,12 @@
-from .scorecard import Scorecard
-from .plots import plot_auc_roc, plot_cap, plot_ks
+from .counterfactual import Counterfactual
 from .monitoring import ScorecardMonitoring
+from .plots import plot_auc_roc, plot_cap, plot_ks
+from .scorecard import Scorecard
 
 
 __all__ = ["Scorecard",
            "ScorecardMonitoring",
            "plot_auc_roc",
            "plot_cap",
-           "plot_ks"]
+           "plot_ks",
+           "Counterfactual"]
